@@ -69,7 +69,7 @@
 
 #define _(text) dgettext(GETTEXT_PACKAGE, text)
 
-#define NUM_PIXBUFS 7*5
+#define NUM_PIXBUFS 7*5*2
 #define HILDON_STATUS_BAR_BORDER_WIDTH 20
 #define MENU_WINDOW_WIDTH 400
 
@@ -107,7 +107,7 @@
 typedef struct _AdvancedBacklightPluginPrivate AdvancedBacklightPluginPrivate;
 struct _AdvancedBacklightPluginPrivate
 {
-  GdkPixbuf *pixbuf[NUM_BRIGHTNESS_ICONS][NUM_VOLUME_ICONS];
+  GdkPixbuf *pixbuf[NUM_BRIGHTNESS_ICONS][NUM_VOLUME_ICONS][2];
   GtkWidget *icon;
   GtkWidget *button;
   GtkWidget *menu;
@@ -851,8 +851,13 @@ advanced_backlight_plugin_update_volume (AdvancedBacklightPlugin * vsp)
   priv->mute = hildon_volumebar_get_mute (HILDON_VOLUMEBAR (priv->volume_slider));
   volume = (gint) hildon_volumebar_get_level (HILDON_VOLUMEBAR (priv->volume_slider));
   if (priv->mute)
+  {
     volume *= -1;
-  g_string_printf (priv->volume_level_string, "%4d", volume);
+    g_string_printf (priv->volume_level_string, "%4d-", volume);
+  }
+  else
+    g_string_printf (priv->volume_level_string, "%4d", volume);
+
   gtk_label_set_text (GTK_LABEL (priv->volume_level_label), (priv->volume_level_string)->str);
   priv->volume_level = volume;
   advanced_backlight_plugin_update_icons (vsp);
@@ -1047,7 +1052,7 @@ advanced_backlight_plugin_create_menu (AdvancedBacklightPlugin * vsp)
   gtk_box_pack_start (GTK_BOX (hbox3), label, TRUE, TRUE, 0);
 
   priv->volume_level_string = g_string_new ("   ");
-  g_string_printf (priv->volume_level_string, "%4d", 50);
+  g_string_printf (priv->volume_level_string, "%4d", priv->volume_level);
   priv->volume_level_label = gtk_label_new ((priv->volume_level_string)->str);
   gtk_misc_set_alignment (GTK_MISC (priv->volume_level_label), 1.0, 0.5);
   gtk_widget_modify_font (GTK_WIDGET (priv->volume_level_label), small_pfd);
@@ -1369,10 +1374,10 @@ advanced_backlight_plugin_dsme_update_brightness_thread (gpointer d)
         {
           g_debug ("priv->brightness_level=%d\n", value);
 
-          if (priv->is_770)
+          //if (priv->is_770)
             advanced_backlight_plugin_770_update_brightness_value (priv, value);
-          else
-            advanced_backlight_plugin_dsme_update_brightness_value (priv, value);
+          //else
+          //  advanced_backlight_plugin_dsme_update_brightness_value (priv, value);
           prev_value = value;
         }
     }
@@ -1692,8 +1697,8 @@ static void
 advanced_backlight_plugin_load_icons (AdvancedBacklightPlugin * vsp)
 {
   AdvancedBacklightPluginPrivate *priv = ADVANCED_BACKLIGHT_PLUGIN_GET_PRIVATE (vsp);
-  gint i, j;
-  gchar icon_name[30];
+  gint i, j, m;
+  gchar icon_name[32];
   gchar *file_name;
   GError *err;
 
@@ -1701,24 +1706,27 @@ advanced_backlight_plugin_load_icons (AdvancedBacklightPlugin * vsp)
     {
       for (j = 0; j < NUM_VOLUME_ICONS; j++)
         {
-          if (j == NUM_VOLUME_ICONS - 1)
-            snprintf (icon_name, 30, "adv-backlight-icon-%d.m.png", i + 1);
-          else
-            snprintf (icon_name, 30, "adv-backlight-icon-%d.%d.png", i + 1, j);
-
-          file_name = g_build_filename (ICON_DIR, priv->current_theme, icon_name, NULL);
-          if (priv->pixbuf[i][j] != NULL)
-            {
-              gdk_pixbuf_unref (priv->pixbuf[i][j]);
-            }
-          err = NULL;
-          if (!(priv->pixbuf[i][j] = gdk_pixbuf_new_from_file (file_name, &err)))
-            {
-              g_critical ("Unable to read file: %s\n", err->message);
-              g_error_free (err);
-            }
-
-          g_free (file_name);
+          for (m = 0; m < 2; m++)
+	    {
+            if (m == 0)
+              snprintf (icon_name, 30, "adv-backlight-icon-%d.%d.u.png", i, j);
+	    else
+              snprintf (icon_name, 30, "adv-backlight-icon-%d.%d.m.png", i, j);
+  
+            file_name = g_build_filename (ICON_DIR, priv->current_theme, icon_name, NULL);
+            if (priv->pixbuf[i][j][m] != NULL)
+              {
+                gdk_pixbuf_unref (priv->pixbuf[i][j][m]);
+              }
+            err = NULL;
+            if (!(priv->pixbuf[i][j][m] = gdk_pixbuf_new_from_file (file_name, &err)))
+              {
+                g_critical ("Unable to read file: %s\n", err->message);
+                g_error_free (err);
+              }
+  
+            g_free (file_name);
+	    }
         }
     }
 }
@@ -1731,24 +1739,19 @@ advanced_backlight_plugin_update_icons (AdvancedBacklightPlugin * vsp)
 
   g_debug ("%s\n", __PRETTY_FUNCTION__);
 
-  volume = priv->volume_level;
-  if (priv->mute)
+  volume = ABS(priv->volume_level);
+  volume_icon = volume / (100 / (NUM_VOLUME_ICONS - 1));
+  if (volume_icon > NUM_VOLUME_ICONS - 1)
     volume_icon = NUM_VOLUME_ICONS - 1;
-  else
-    {
-      volume_icon = volume / (100 / (NUM_VOLUME_ICONS - 1));
-      if (volume_icon > NUM_VOLUME_ICONS - 2)
-        volume_icon = NUM_VOLUME_ICONS - 2;
-    }
 
   brightness_icon = ((NUM_BRIGHTNESS_ICONS - 1) * priv->brightness_level) / priv->max_brightness;
   if (brightness_icon > NUM_BRIGHTNESS_ICONS - 1)
     brightness_icon = NUM_BRIGHTNESS_ICONS - 1;
 
   if (!priv->icon)
-    priv->icon = gtk_image_new_from_pixbuf (priv->pixbuf[brightness_icon][volume_icon]);
+    priv->icon = gtk_image_new_from_pixbuf (priv->pixbuf[brightness_icon][volume_icon][priv->mute]);
   else
-    gtk_image_set_from_pixbuf (GTK_IMAGE (priv->icon), priv->pixbuf[brightness_icon][volume_icon]);
+    gtk_image_set_from_pixbuf (GTK_IMAGE (priv->icon), priv->pixbuf[brightness_icon][volume_icon][priv->mute]);
 
 }
 
